@@ -17,14 +17,14 @@ class DefaultMeta(Meta):
 		self.schema_name = None
 		self.component_name = None
 
-	def initialize(self, definition, component_name_suffix='Model'):
+	def initialize(self, definition, component_name_suffix='Model', display_name=None):
 		if definition.is_object():
 			self.schema_name = definition.data_format.model_name
 			self.component_name = self.schema_name
 		elif definition.is_array():
 			self.component_name = definition.data_format
 		else:
-			self.component_name = self.component_name_strategy.create_name(definition, component_name_suffix)
+			self.component_name = self.component_name_strategy.create_name(definition, component_name_suffix, display_name)
 
 
 class Definition:
